@@ -37,7 +37,6 @@
 
 SelectDeviceAndFilesPage::SelectDeviceAndFilesPage(SendFileWizard *wizard)
     : QWizardPage(wizard)
-    , m_dialog(0)
     , m_wizard(wizard)
 {
     setupUi(this);
@@ -70,7 +69,12 @@ void SelectDeviceAndFilesPage::openFileDialog()
     if (files.isEmpty()) {
         selectLbl->setText(i18n("Select one or more files:"));
     } else {
-        selectLbl->setText(i18n("Selected files: <b>%1</b>", files.count()));
+        QStringList fileNames;
+        Q_FOREACH (const QString &file, files) {
+            QFileInfo info(file);
+            fileNames.append(info.fileName());
+        }
+        selectLbl->setText(i18n("Selected files: <b>%1</b>", fileNames.join(QLatin1String(", "))));
     }
 
     m_wizard->setFiles(files);
