@@ -28,6 +28,7 @@
 #include "pages/selectdevicepage.h"
 #include "pages/selectfilespage.h"
 #include "pages/connectingpage.h"
+#include "pages/failpage.h"
 
 #include <QUrl>
 #include <QPushButton>
@@ -49,7 +50,6 @@ SendFileWizard::SendFileWizard(const QString &device, const QStringList &files)
     , m_files(files)
     , m_job(0)
 {
-    setWindowTitle(i18n("Bluetooth Send Files"));
     setOption(NoCancelButton, false);
     setButton(QWizard::NextButton, new QPushButton(QIcon::fromTheme(QStringLiteral("document-export")), i18n("Send Files")));
     setButton(QWizard::CancelButton, new QPushButton(QIcon::fromTheme(QStringLiteral("dialog-cancel")), i18n("Cancel")));
@@ -112,7 +112,7 @@ void SendFileWizard::setDevice(BluezQt::DevicePtr device)
     m_device = device;
 }
 
-void SendFileWizard::startTransfer()
+void SendFileWizard::startTransfer(const QDBusObjectPath &session)
 {
     if (m_files.isEmpty()) {
         qCDebug(SENDFILE) << "No files to send";
@@ -121,9 +121,10 @@ void SendFileWizard::startTransfer()
 
     if (!m_device) {
         qCDebug(SENDFILE) << "No device selected";
+        return;
     }
 
-    m_job = new SendFilesJob(m_files, m_device);
+    m_job = new SendFilesJob(m_files, m_device, session);
     connect(m_job, &SendFilesJob::destroyed, qApp, &QCoreApplication::quit);
 
     KIO::getJobTracker()->registerJob(m_job);
@@ -169,7 +170,8 @@ void SendFileWizard::initJobResult(BluezQt::InitManagerJob *job)
         }
     }
 
-    addPage(new ConnectingPage());
+    addPage(new ConnectingPage(this));
+    addPage(new FailPage(this));
 
     // Only show wizard after init is completed
     show();
