@@ -45,6 +45,7 @@ QString WizardAgent::pin()
 void WizardAgent::setPin(const QString &pin)
 {
     m_pin = pin;
+    m_fromDatabase = false;
 }
 
 bool WizardAgent::isFromDatabase()
@@ -54,10 +55,7 @@ bool WizardAgent::isFromDatabase()
 
 QString WizardAgent::getPin(BluezQt::DevicePtr device)
 {
-    if (!m_pin.isEmpty() || !device) {
-        return m_pin;
-    }
-
+    m_fromDatabase = false;
     m_pin = QString::number(KRandom::random());
     m_pin = m_pin.left(6);
 
@@ -72,8 +70,10 @@ QString WizardAgent::getPin(BluezQt::DevicePtr device)
 
     QXmlStreamReader xml(&file);
 
-    int deviceType = device->deviceType();
-    int xmlType = 0;
+    QString deviceType = BluezQt::Device::typeToString(device->type());
+    if (deviceType == QLatin1String("audiovideo")) {
+        deviceType = QStringLiteral("audio");
+    }
 
     while (!xml.atEnd()) {
         xml.readNext();
@@ -87,9 +87,7 @@ QString WizardAgent::getPin(BluezQt::DevicePtr device)
         }
 
         if (attr.hasAttribute(QLatin1String("type")) && attr.value(QLatin1String("type")) != QLatin1String("any")) {
-            xmlType = BluezQt::Device::stringToType(attr.value(QLatin1String("type")).toString());
-            if (deviceType != xmlType) {
-                xmlType = 0;
+            if (deviceType != attr.value(QLatin1String("type")).toString()) {
                 continue;
             }
         }
@@ -164,8 +162,3 @@ void WizardAgent::requestConfirmation(BluezQt::DevicePtr device, const QString &
 
     Q_EMIT confirmationRequested(passkey, req);
 }
-
-void WizardAgent::release()
-{
-    Q_EMIT agentReleased();
-}
